@@ -19,7 +19,7 @@ import scipy
 from . import utils
 from .utils import pm
 
-__version__ = "6.6.1"
+__version__ = "7.0.0"
 _log = logging.getLogger("calibr8")
 
 
@@ -515,7 +515,13 @@ class CalibrationModel(DistributionMixin):
 
         params = self.predict_dependent(x, theta=theta)
         if utils.istensor(x) or utils.istensor(theta):
-            if pm.Model.get_context(error_if_none=False) is not None:
+            try:
+                import pytensor.tensor as pt
+            except ModuleNotFoundError:
+                import aesara.tensor as pt
+
+            pmodel = pm.Model.get_context(error_if_none=False)
+            if pmodel is not None:
                 if replicate_id and dependent_key:
                     warnings.warn(
                         "The `replicate_id` and `dependent_key` parameters are deprecated. Use `name` instead.",
@@ -525,16 +531,13 @@ class CalibrationModel(DistributionMixin):
                 if not name:
                     raise ValueError("A `name` must be specified for the PyMC likelihood.")
                 rv = self.pymc_dist(name, **self.to_pymc(*params), observed=y, **dist_kwargs or {})
+                return pmodel.logp([rv], sum=True)
             else:
                 rv = self.pymc_dist.dist(**self.to_pymc(*params), **dist_kwargs or {})
-            # The API to get log-likelihood tensors differs between PyMC versions
-            if pm.__version__[0] == "3":
-                if isinstance(rv, pm.model.ObservedRV):
-                    return rv.logpt.sum()
-                elif isinstance(rv, pm.Distribution):
-                    return rv.logp(y).sum()
-            else:
-                return pm.joint_logpt(rv, y, sum=True)
+                L = pm.logp(rv, y).sum()
+                # Check that there are no random variables in the graph leading to the logp
+                utils._check_no_rvs([L])
+                return L
         else:
             logp = None
             if hasattr(self.scipy_dist, "logpdf"):
