@@ -15,25 +15,18 @@ import calibr8.utils
 
 try:
     try:
-        import pymc3 as pm
-        import theano as backend
-        import theano.tensor as at
+        import pytensor as backend
+        import pytensor.tensor as at
     except ModuleNotFoundError:
         import aesara as backend
         import aesara.tensor as at
-        import pymc as pm
+    import pymc as pm
+
     config = backend.config
     HAS_PYMC = True
 except ModuleNotFoundError:
     HAS_PYMC = False
 
-try:
-    import pygmo
-
-    HAS_PYGMO = True
-except ModuleNotFoundError:
-    HAS_PYGMO = False
-
 
 dir_testfiles = pathlib.Path(pathlib.Path(__file__).absolute().parent, "testfiles")
 
@@ -467,6 +460,11 @@ class TestContinuousUnivariateModel:
         x_true = numpy.array([1, 2, 3, 4, 5])
         y_obs = cmodel.predict_dependent(x_true)[0]
 
+        # Make sure that one can't logp graphs that depend on a random variable
+        with pytest.raises(ValueError, match="Random variables detected"):
+            xRV = pm.Normal.dist()
+            cmodel.loglikelihood(x=xRV, y=y_obs, name="L_A01_A")
+
         x_hat = at.vector()
         x_hat.tag.test_value = x_true
         L = cmodel.loglikelihood(x=x_hat, y=y_obs, name="L_A01_A")
@@ -499,12 +497,11 @@ class TestContinuousUnivariateModel:
         assert L.ndim == 0
 
         # PyMC v4 returns the RV, but for .eval() we need the RV-value-variable
-        if pm.__version__[0] != "3":
-            x_hat = pmodel.rvs_to_values[x_hat]
+        x_vv = pmodel.rvs_to_values[x_hat]
 
         # compare the two loglikelihood computation methods
         x_test = numpy.random.normal(x_true, scale=0.1)
-        actual = L.eval({x_hat: x_test})
+        actual = L.eval({x_vv: x_test})
         expected = cmodel.loglikelihood(x=x_test, y=y_obs)
         assert numpy.ndim(expected) == 0
         assert numpy.ndim(actual) == 0
@@ -986,10 +983,10 @@ class TestSymbolicModelFunctions:
             y = function(x, theta)
             assert isinstance(y, at.TensorVariable)
 
-            # compile Theano/Aesara function
+            # compile PyTensor function
             f = backend.function([x], [y])
 
-            # check equivalence of numpy and Theano/Aesara backend computation
+            # check equivalence of numpy and PyTensor backend computation
             x_test = [1, 2, 4]
             numpy.testing.assert_almost_equal(f(x_test)[0], function(x_test, theta))
         return
@@ -1229,13 +1226,12 @@ class TestOptimization:
     def test_fit_checks_guess_and_bounds_count(self):
         theta_mu, theta_scale, theta, em, x, y = self._get_test_model()
         common = dict(model=em, independent=x, dependent=y)
-        for fit in (calibr8.fit_scipy, calibr8.fit_pygmo):
-            # wrong guess
-            with pytest.raises(ValueError):
-                fit(**common, theta_guess=numpy.ones(14), theta_bounds=[(-5, 5)] * len(theta))
-            # wrong bounds
-            with pytest.raises(ValueError):
-                fit(**common, theta_guess=numpy.ones_like(theta), theta_bounds=[(-5, 5)] * 14)
+        # wrong guess
+        with pytest.raises(ValueError):
+            calibr8.fit_scipy(**common, theta_guess=numpy.ones(14), theta_bounds=[(-5, 5)] * len(theta))
+        # wrong bounds
+        with pytest.raises(ValueError):
+            calibr8.fit_scipy(**common, theta_guess=numpy.ones_like(theta), theta_bounds=[(-5, 5)] * 14)
         return
 
     def test_fit_scipy(self, caplog):
@@ -1273,45 +1269,6 @@ class TestOptimization:
         numpy.testing.assert_array_equal(em.cal_dependent, y)
         pass
 
-    @pytest.mark.xfail(
-        reason="PyGMO and PyMC have dependencies (cloudpickle/dill) that are currently incompatible. See https://github.com/uqfoundation/dill/issues/383"
-    )
-    @pytest.mark.skipif(not HAS_PYGMO, reason="requires PyGMO")
-    def test_fit_pygmo(self, caplog):
-        numpy.random.seed(1234)
-        theta_mu, theta_scale, theta, em, x, y = self._get_test_model()
-        theta_fit, history = calibr8.fit_pygmo(
-            em,
-            independent=x,
-            dependent=y,
-            theta_bounds=[(-5, 5)] * len(theta_mu) + [(0.02, 1), (1, 20)],
-            evolutions=5,
-        )
-        for actual, desired, atol in zip(theta_fit, theta, [0.10, 0.05, 0.2, 2]):
-            numpy.testing.assert_allclose(actual, desired, atol=atol)
-        assert isinstance(history, list)
-        numpy.testing.assert_array_equal(em.theta_fitted, theta_fit)
-        assert em.theta_bounds is not None
-        assert em.theta_guess is None
-        numpy.testing.assert_array_equal(em.cal_independent, x)
-        numpy.testing.assert_array_equal(em.cal_dependent, y)
-
-        with caplog.at_level(logging.WARNING):
-            x[0] = -numpy.inf
-            y[-1] = float("nan")
-            calibr8.fit_pygmo(
-                em,
-                independent=x,
-                dependent=y,
-                theta_bounds=[(-5, 5)] * len(theta_mu) + [(0.02, 1), (1, 20)],
-                evolutions=5,
-            )
-        assert "2 elements" in caplog.text
-        # inf/nan should only be ignored for fitting
-        numpy.testing.assert_array_equal(em.cal_independent, x)
-        numpy.testing.assert_array_equal(em.cal_dependent, y)
-        pass
-
     def test_fit_scipy_global(self, caplog):
         numpy.random.seed(2345)
         theta_mu, theta_scale, theta, em, x, y = self._get_test_model()
